@@ -61,6 +61,7 @@ def Complex2Iiqq( complexList):
     return iqiqiqList
 
 
+
 def WriteIqw( iqData, FileName, AppendExisting = False):
     """Writes an IQW file (file of binary floats).
     iqData can be a list of complex or list of floats. List of floats will
@@ -118,8 +119,8 @@ def ReadIqw( FileName, iqiq = True):
         data = Iiqq2Complex( data)
     
     return data
-        
-                         
+
+
 
 def WriteWv( iqData, fSamplingRate, FileName):
     """Writes a WV file.
@@ -176,19 +177,25 @@ def WriteWv( iqData, fSamplingRate, FileName):
         logging.error("File (" + FileName +") write error!" )
         
     return NumberOfSamples
-    
-    
-def ReadWv( FileName):
+
+
+
+def ReadWv( FileName, ReadData = True):
     """Reads a WV file. Returns a list with complex numbers (I/Q) and the sampling rate
-    iqiqiqList,fs = ReadWv("MyFile.wv")"""
+    iqiqiqList,fs = ReadWv("MyFile.wv")
+    ReadData:   if set to False, we'll only return the parameters from the header"""
     
     import re
     import struct
     import logging
-    
+    from numpy import NaN
+
     try:
         file = open(FileName, "rb")
-        data = file.read()   
+        if( ReadData):
+            data = file.read()
+        else:
+            data = file.read( 6000)     # for the header, 62 kB should be sufficient
         file.close()
     except:
         logging.error( "File open error ("+ FileName+")!")
@@ -204,18 +211,40 @@ def ReadWv( FileName):
         res = re.search("WAVEFORM.{0,20}:.{0,3}#",tags)
         if res != None:
             binaryStart = res.span()[1]
-    
+
     if (Counter > len(data)) & (binaryStart == 0):
-        logging.warn( "Required tags not found, potentially incompatible file format!")
-        
+        logging.warning( "Required tags not found, potentially incompatible file format!")
+
     res = re.search("SAMPLES[ ]*:[ ]*(?P<NumberOfSamples>[0-9]*)",tags)
-    NumberOfSamples = int( res.group("NumberOfSamples"))
-    res = re.search("CLOCK[ ]*:[ ]*(?P<SamplingRate>[0-9]*)",tags)
-    SamplingRate = float( res.group("SamplingRate"))
-    data = list(struct.unpack("h"*NumberOfSamples*2, data[binaryStart:-1]))
-    data = list(map( lambda x: x/32767.0, data ))
-    data = Iqiq2Complex( data)
-    return data,SamplingRate
+    if res:
+        NumberOfSamples = int( res.group("NumberOfSamples"))
+    else:
+        NumberOfSamples = NaN
+    res = re.search("CLOCK[ ]*:[ ]*(?P<SamplingRate>[0-9]*.[0-9]*[eE]?[+\-]?[0-9]*)",tags)
+    if res:
+        SamplingRate = float( res.group("SamplingRate"))
+    else:
+        SamplingRate = NaN
+    res = re.search("LEVEL OFFS[ ]*:[ ]*(?P<RMSLevelOffset>[0-9]*.[0-9]*)",tags)
+    if res:
+        RmsLevelOffset = float( res.group("RMSLevelOffset"))
+    else:
+        RmsLevelOffset = NaN
+    res = re.search("COMMENT:Signal generated for SMx RMS level[ ]*:[ ]*(?P<RfRmsLevel>[0-9]*.[0-9]*)",tags)
+    if res:
+        RfRmsLevel = float( res.group("RfRmsLevel"))
+    else:
+        RfRmsLevel = NaN
+
+    if ReadData:
+        data = list(struct.unpack("h"*NumberOfSamples*2, data[binaryStart:-1]))
+        data = list(map( lambda x: x/32767.0, data ))
+        data = Iqiq2Complex( data)
+    
+    if ReadData:
+        return data,SamplingRate
+    else:
+        return SamplingRate,NumberOfSamples,RmsLevelOffset,RfRmsLevel
 
 
 
@@ -416,7 +445,7 @@ def Iqw2Iqtar( FileName, fs, keepIqw = False):
         logging.error("IqTar (" + FileName +") write error!" )
     
     return
-    
+
 
 
 def Iqw2Wv( FileName, fs, keepIqw = False):
@@ -506,11 +535,9 @@ def Iqw2Wv( FileName, fs, keepIqw = False):
         os.remove( FileName)
     except:
         logging.error("File (" + FileName +") write error!" )    
-        
-    
 
 
-    
+
 if __name__ == "__main__":
     # execute only if run as a script
     pass   
